@@ -1,7 +1,4 @@
-print.evReturn <- function(x, ...){
-    if (class(x) != "evReturn") {
-        stop("Please provide an object from 'evReturn'.\n")
-    }    
+print.evReturn <- function(x, ...){  
     cat("\n==================================================================\n")
     cat("    Regression coefficients by firm\n")
     cat("==================================================================\n")
