@@ -1,8 +1,5 @@
 print.maTrend <- function(x, ...)
 {
-  if (class(x) != "maTrend") {
-    stop("Please provide an object from 'maTrend()'.\n")
-  }  
   cat("\n===========================================")
   cat("\nCalculated Probability Matrix\n")
   cat("===========================================\n")
